#!/bin/ksh
WAR_FILE=customer_care.war
CMD=$(basename $0)
FILE_LOCATION=`dirname $0`
FLCC_LOGS=$TIP_HOME/logs/customer_care
LOGFILE=$TIP_HOME/logs/customer_care/configure_flcc.log
INSTALL=NO
REMOVE=NO

while [ $# != 0 ]
do
  case "$1" in

        -profile)
               shift
               if [ $# = 0 ]
               then
                 echo "${CMD} [${PID}]: ERROR: TIP Profile expected"
                 usage
                 exit 1
               fi
               export TIP_PROFILE=$1
               ;;
        -user)
               shift
               if [ $# = 0 ]
               then
                 echo "${CMD} [${PID}]: ERROR: TIP User expected"
                 usage
                 exit 1
               fi
               export TIP_USER=$1
               ;;
        -passwd)
               shift
               if [ $# = 0 ]
               then
                 echo "${CMD} [${PID}]: ERROR: TIP Password expected"
                 usage
                 exit 1
               fi
               export TIP_PASSWD=$1
               ;;
               
        -mode)
               shift
               case $1 in
                 install)
                          INSTALL=YES
                          ;;
                  remove)
                          REMOVE=YES
                          ;;
                       *)
                          echo "${CMD} [${PID}]: ERROR: install or remove directive expected"
                          usage
                          ;;
               esac
               ;;

             *)
               usage
               ;;
  esac
  shift
done


usage()
{
# echo usage statement here
  echo "${CMD}: [${PID}]: Usage: ${CMD} -profile <TIP Profile> -user <TIP Admin User> -passwd <TIP Admin Password> -mode <install|remove>"
  return 0

}

create_logging()
{
  mkdir -p $FLCC_LOGS 
}

deploy_components()
{

  echo "Deploying Components... \c"
  # copy start script to $TIP_HOME/bin
  cp $FILE_LOCATION/startflcc.sh $TIP_HOME/bin
  chmod 755 $TIP_HOME/bin/startflcc.sh
  
  create_logging
  
  # extract war file to $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear
  mkdir -p $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear/customer_care.war
  cp $FILE_LOCATION/${WAR_FILE} $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear/customer_care.war
  jar -xf $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear/customer_care.war/customer_care.war
  rm $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear/customer_care.war/customer_care.war
  echo "done."
}

remove_components()
{

  echo "Removing Components... \c"
  # remove start script
  rm $TIP_HOME/bin/startflcc.sh
  
  # Remove logging area
  rm -rf $FLCC_LOGS 
  
  # Remove web-app
  rm -rf $TIP_HOME/profiles/TIPProfile/installedApps/TIPCell/isc.ear/customer_care.war
  echo "done."
}

was_install_config()
{
	#Configure web-app
	echo "Updating ${TIP_PROFILE} configuration... \c"
    ${TIP_HOME}/bin/wsadmin.sh -profileName ${TIP_PROFILE} \
          -username ${TIP_USER} -password ${TIP_PASSWD} <<EOF >>$LOGFILE
       \$AdminApp update isc modulefile {-operation add -contents ${FILE_LOCATION}/${WAR_FILE} -contenturi ${WAR_FILE} -contextroot /ibm/customer_care -usedefaultbindings -custom paavalidation=false -MapWebModToVH {{.* .* default_host}}}
       \$AdminConfig save
EOF
     [ $? -ne 0 ] && echo "ERROR: Update of ${TIP_PROFILE} configuration failed." && exit 1
     echo "done."
     echo "Updating security configuration...\c"
     echo  "\nCTAUTHENTICATION {\
com.comnitel.jaas.ldap.LdapLoginModule optional;\
};" >> ${TIP_HOME}/profiles/TIPProfile/properties/wsjaas.conf
     echo "done."    
  return 0
	
}

was_uninstall_config()
{		
	#Deconfigure web-app
     echo "Updating ${TIP_PROFILE} configuration... \c"
     ${TIP_HOME}/bin/wsadmin.sh -profileName ${TIP_PROFILE} \
          -username ${TIP_USER} -password ${TIP_PASSWD} <<EOF >>$LOGFILE
       \$AdminApp update isc modulefile {-operation delete -contenturi customer_care.war}
       \$AdminConfig save
EOF
    [ $? -ne 0 ] && echo "ERROR: Update of ${TIP_PROFILE} configuration failed." && exit 1
     echo "done."
}

check_env()
{
    # Check TIP_HOME is set
    if [ "X$TIP_HOME" = "X" ]; then
        echo "ERROR: TIP_HOME variable is mandatory"
        usage
        exit 1
    fi

    # Check the flcc war file is present
    if [ ! -f $FILE_LOCATION/${WAR_FILE} ]; then
       echo "ERROR: Web archive does not exist : $FILE_LOCATION/${WAR_FILE}"
       exit 1
    fi
    
    # Check TIP_HOME set correctly
    if [ ! -f $TIP_HOME/bin/startServer.sh ]; then
       echo "ERROR: TIP_HOME variable incorrectly set : $TIP_HOME"
       exit 1
    fi
}

restart_tip()
{
	echo "The TIP Server must now be restarted"
}


# FLCC Install procedure

if [ "${INSTALL}" = "NO"  -a "${REMOVE}" = "NO" ]
then
  echo "${CMD} [${PID}]: ERROR: Must specify a mode (install or remove)"
  usage
  exit 1
fi

if [ "${INSTALL}" = "YES" ]
then
    check_env

    deploy_components

    was_install_config

    restart_tip
fi

if [ "${REMOVE}" = "YES" ]
then
    check_env
    
    create_logging
    
    was_uninstall_config
    
    remove_components
    
    restart_tip
fi


